@@ -4,6 +4,7 @@ use std::sync::Arc;
 use std::time::{Duration, Instant};
 use udp2p_protocol::protocol::{InnerKey, Packet, AddressBytes, Packets};
 use udp2p_utils::utils::ByteRep;
+use log::info;
 
 /// A pseudo-guaranteed deliver wrapper for UDP sockets to ensure that
 /// packets are either delivered, or are resent to the destination.
@@ -165,7 +166,9 @@ impl GDUdp {
         }
         if let Some(bytes) = packet.as_bytes() {
             if let Err(e) = sock.send_to(&bytes, peer) {
-                println!("Error sending packet to {:?}:\n{:?}", peer, e)
+                info!("Error sending packet to {:?}:\n{:?}", peer, e)
+            } else {
+                info!("Sent packet {:?} to {:?}", &packet.id, peer)
             }
         }
     }
